# coding: utf-8

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic.v1 import BaseModel

class NullTune(BaseModel):
    """
    A null tune so the tagged union works.  # noqa: E501
    """
    tune_type: Optional[Any] = None
    __properties = ["tune_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NullTune:
        """Create an instance of NullTune from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if tune_type (nullable) is None
        # and __fields_set__ contains the field
        if self.tune_type is None and "tune_type" in self.__fields_set__:
            _dict['tune_type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NullTune:
        """Create an instance of NullTune from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return NullTune.parse_obj(obj)

        _obj = NullTune.parse_obj({
            "tune_type": obj.get("tune_type")
        })
        return _obj


