# coding: utf-8

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from enum import Enum





class TuneStatus(str, Enum):
    """
    The status of the tune job.
    """

    """
    allowed enum values
    """
    PENDING = 'pending'
    RUNNING = 'running'
    SUCCEEDED = 'succeeded'
    CANCELLED = 'cancelled'
    FAILED = 'failed'

    @classmethod
    def from_json(cls, json_str: str) -> TuneStatus:
        """Create an instance of TuneStatus from a JSON string"""
        return TuneStatus(json.loads(json_str))


