# coding: utf-8

"""
    fine-tuning-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic.v1 import BaseModel, Field, StrictStr
from clients.fine_tuning.models.base_engine import BaseEngine

class LoraTuneCheckpoint(BaseModel):
    """
    A checkpoint used for a LoRA Tune.  # noqa: E501
    """
    checkpoint_id: StrictStr = Field(..., description="The checkpoint asset ID.")
    engine: Optional[BaseEngine] = None
    name: Optional[StrictStr] = None
    __properties = ["checkpoint_id", "engine", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LoraTuneCheckpoint:
        """Create an instance of LoraTuneCheckpoint from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if engine (nullable) is None
        # and __fields_set__ contains the field
        if self.engine is None and "engine" in self.__fields_set__:
            _dict['engine'] = None

        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict['name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LoraTuneCheckpoint:
        """Create an instance of LoraTuneCheckpoint from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LoraTuneCheckpoint.parse_obj(obj)

        _obj = LoraTuneCheckpoint.parse_obj({
            "checkpoint_id": obj.get("checkpoint_id"),
            "engine": obj.get("engine"),
            "name": obj.get("name")
        })
        return _obj


