from __future__ import annotations
# coding: utf-8

"""
    asset-lake-api-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from enum import Enum





class AssetType(str, Enum):
    """
    AssetType
    """

    """
    allowed enum values
    """
    FILE = 'file'
    CHECKPOINT = 'checkpoint'
    LORA = 'lora'
    TEXTUAL_INVERSION = 'textual_inversion'
    VAE = 'vae'
    VOLUME = 'volume'

    @classmethod
    def from_json(cls, json_str: str) -> AssetType:
        """Create an instance of AssetType from a JSON string"""
        return AssetType(json.loads(json_str))


